@@ -37,11 +37,16 @@
 #include <bonobo.h>
 #include <stdio.h>
 #include <glib.h>
+#include <glib/gstdio.h>
 #include <errno.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
 
+#ifndef O_BINARY
+#define O_BINARY 0
+#endif
+
 #include <gtk/gtkscrolledwindow.h>
 
 #include <glade/glade.h>
@@ -49,6 +54,7 @@
 #include "Editor.h"
 
 #include "gtkhtml.h"
+#include "gtkhtml-private.h"
 #include "gtkhtml-properties.h"
 #include "htmlcursor.h"
 #include "htmlengine.h"
@@ -243,12 +249,9 @@ load_from_file (GtkHTML *html,
 	int fd;
         char *path;
 
-        if (strncmp (url, "file:", 5) == 0)
-		path = g_filename_from_uri(url, NULL, NULL);
-	else
-		path = g_strdup(url);
+	path = gtk_html_filename_from_uri (url);
 
-	fd = open (path, O_RDONLY);
+	fd = g_open (path, O_RDONLY|O_BINARY, 0);
 	g_free(path);
 
 	if (fd == -1) {
